diff lib/timevar.h @ 39871:08db1aa192ec

timevar: Small tweaks. * lib/timevar.h: Fix comments. Add parameter names to function declarations. * lib/timevar.c: Include timevar.h immediately after config.h. * lib/timevar.def: Fix comments. * modules/timevar (Maintainer): List Akim Demaille.
author Bruno Haible <bruno@clisp.org>
date Sun, 30 Sep 2018 19:36:29 +0200
parents f315e5e30ddd
children 13eae48fd484
line wrap: on
line diff
--- a/lib/timevar.h	Sun Sep 30 19:27:56 2018 +0200
+++ b/lib/timevar.h	Sun Sep 30 19:36:29 2018 +0200
@@ -1,4 +1,4 @@
 /* Timing variables for measuring compiler performance.
 
    Copyright (C) 2000, 2002, 2004, 2009-2015, 2018 Free Software
    Foundation, Inc.
@@ -22,7 +22,7 @@
 #define _TIMEVAR_H
 
 /* Timing variables are used to measure elapsed time in various
-   portions of the compiler.  Each measures elapsed user, system, and
+   portions of the application.  Each measures elapsed user, system, and
    wall-clock time, as appropriate to and supported by the host
    system.
 
@@ -86,7 +86,7 @@
 
    TIMEVAR cannot be running as a standalone timer.  */
 
-void timevar_push (timevar_id_t);
+void timevar_push (timevar_id_t timevar);
 
 /* Pop the topmost timing variable element off the timing stack.  The
    popped variable must be TIMEVAR.  Elapsed time since the that
@@ -94,28 +94,29 @@
    stack when the element above it was popped off, is credited to that
    timing variable.  */
 
-void timevar_pop (timevar_id_t);
+void timevar_pop (timevar_id_t timevar);
 
 /* Start timing TIMEVAR independently of the timing stack.  Elapsed
    time until timevar_stop is called for the same timing variable is
    attributed to TIMEVAR.  */
 
-void timevar_start (timevar_id_t);
+void timevar_start (timevar_id_t timevar);
 
 /* Stop timing TIMEVAR.  Time elapsed since timevar_start was called
    is attributed to it.  */
 
-void timevar_stop (timevar_id_t);
+void timevar_stop (timevar_id_t timevar);
+
 /* Fill the elapsed time for TIMEVAR into ELAPSED.  Returns
    update-to-date information even if TIMEVAR is currently running.  */
 
-void timevar_get (timevar_id_t, struct timevar_time_def *);
+void timevar_get (timevar_id_t timevar, struct timevar_time_def *elapsed);
 
 /* Summarize timing variables to FP.  The timing variable TV_TOTAL has
    a special meaning -- it's considered to be the total elapsed time,
    for normalizing the others, and is displayed last.  */
 
-void timevar_print (FILE *);
+void timevar_print (FILE *fp);
 
 /* Set to to nonzero to enable timing variables.  */
 extern int timevar_enabled;
@@ -1,4 +1,4 @@
-/* Timing variables for measuring compiler performance.
+/* Timing variables for measuring application performance.
 
    Copyright (C) 2000, 2002, 2004, 2009-2015, 2018 Free Software